@@ -382,7 +382,7 @@ func (iterator *hostIterator) sendReservationGetPage() ([]keaconfig.Reservation,
 		arguments["source-index"] = iterator.sourceIndex
 	}
 	// Prepare the command.
-	command := keactrl.NewCommand("reservation-get-page", daemons, &arguments)
+	command := keactrl.NewCommand("reservation-get-page", daemons, arguments)
 	commands := []keactrl.SerializableCommand{command}
 	response := make([]ReservationGetPageResponse, 1)
 	ctx := context.Background()
