@@ -85,7 +85,6 @@ func TestUpdateKeaDHCPDaemon(t *testing.T) {
 
 	daemon.KeaDaemon.KeaDHCPDaemon.Stats.RPS1 = 1000
 	daemon.KeaDaemon.KeaDHCPDaemon.Stats.RPS2 = 2000
-	daemon.KeaDaemon.KeaDHCPDaemon.Stats.AddrUtilization = 90
 
 	err = UpdateDaemon(db, daemon)
 	require.NoError(t, err)
@@ -105,7 +104,6 @@ func TestUpdateKeaDHCPDaemon(t *testing.T) {
 	require.NotNil(t, daemon.KeaDaemon.KeaDHCPDaemon)
 	require.EqualValues(t, 1000, daemon.KeaDaemon.KeaDHCPDaemon.Stats.RPS1)
 	require.EqualValues(t, 2000, daemon.KeaDaemon.KeaDHCPDaemon.Stats.RPS2)
-	require.EqualValues(t, 90, daemon.KeaDaemon.KeaDHCPDaemon.Stats.AddrUtilization)
 }
 
 // Test that Bind9 daemon is properly updated.
