@@ -18,7 +18,7 @@ import { ProgressBarModule } from 'primeng/progressbar'
 import { DialogModule } from 'primeng/dialog'
 import { InputTextModule } from 'primeng/inputtext'
 import { DropdownModule } from 'primeng/dropdown'
-import { MessageService } from 'primeng/api'
+import { ConfirmationService, MessageService } from 'primeng/api'
 import { ToastModule } from 'primeng/toast'
 import { MessageModule } from 'primeng/message'
 import { MessagesModule } from 'primeng/messages'
@@ -41,6 +41,8 @@ import { TagModule } from 'primeng/tag'
 import { ToggleButtonModule } from 'primeng/togglebutton'
 import { MultiSelectModule } from 'primeng/multiselect'
 import { CheckboxModule } from 'primeng/checkbox'
+import { ConfirmDialogModule } from 'primeng/confirmdialog'
+import { InputTextareaModule } from 'primeng/inputtextarea'
 
 // Generated API modules
 import { ApiModule, BASE_PATH, Configuration, ConfigurationParameters } from './backend'
@@ -91,6 +93,8 @@ import { ConfigReviewPanelComponent } from './config-review-panel/config-review-
 import { IdentifierComponent } from './identifier/identifier.component'
 import { AppOverviewComponent } from './app-overview/app-overview.component'
 import { HostFormComponent } from './host-form/host-form.component'
+import { DhcpOptionFormComponent } from './dhcp-option-form/dhcp-option-form.component'
+import { DhcpOptionSetFormComponent } from './dhcp-option-set-form/dhcp-option-set-form.component'
 
 export function cfgFactory() {
     const params: ConfigurationParameters = {
@@ -143,6 +147,8 @@ export function cfgFactory() {
         IdentifierComponent,
         AppOverviewComponent,
         HostFormComponent,
+        DhcpOptionFormComponent,
+        DhcpOptionSetFormComponent,
     ],
     imports: [
         BrowserModule,
@@ -187,6 +193,8 @@ export function cfgFactory() {
         ToggleButtonModule,
         MultiSelectModule,
         CheckboxModule,
+        ConfirmDialogModule,
+        InputTextareaModule,
     ],
     providers: [
         {
@@ -198,6 +206,7 @@ export function cfgFactory() {
             provide: BASE_PATH,
             useValue: environment.apiUrl,
         },
+        ConfirmationService,
         MessageService,
     ],
     bootstrap: [AppComponent],
