@@ -10,13 +10,17 @@ import {
 } from '@angular/forms'
 import { MessageService, SelectItem } from 'primeng/api'
 import { map } from 'rxjs/operators'
+import { collapseIPv6Number, isIPv4, IPv4, IPv4CidrRange, IPv6, IPv6CidrRange, Validator } from 'ip-num'
 import { StorkValidators } from '../validators'
 import { DHCPService } from '../backend/api/api'
 import { Host } from '../backend/model/host'
 import { IPReservation } from '../backend/model/iPReservation'
-import { KeaDaemon } from '../backend/model/keaDaemon'
 import { LocalHost } from '../backend/model/localHost'
 import { Subnet } from '../backend/model/subnet'
+import { HostForm } from '../forms/host-form'
+import { createDefaultDhcpOptionFormGroup } from '../forms/dhcp-option-form'
+import { DhcpOptionSetForm } from '../forms/dhcp-option-set-form'
+import { IPType } from '../iptype'
 import { stringToHex } from '../utils'
 
 /**
@@ -34,7 +38,9 @@ function subnetRequiredValidator(group: FormGroup): ValidationErrors | null {
             err: 'subnet is required for non-global reservations',
         }
         // Highlight the dropdown.
-        group.get('selectedSubnet').setErrors(errs)
+        if (group.get('selectedSubnet').touched && group.get('selectedSubnet').dirty) {
+            group.get('selectedSubnet').setErrors(errs)
+        }
         return errs
     }
     // Clear errors because everything seems fine.
@@ -43,159 +49,96 @@ function subnetRequiredValidator(group: FormGroup): ValidationErrors | null {
 }
 
 /**
- * A form validator checking if a selected DHCP identifier has been specified.
+ * A form validator checking if a selected DHCP identifier has been specified
+ * and does not exceed the maximum length.
  *
  * @param group a selected form group belonging to the ipGroups array.
  * @returns validation errors when no value has been specified in the
  *          idInputHex input box (when selected type is hex) or idInputText
- *          (when selected type is text).
+ *          (when selected type is text). It also returns validation errors
+ *          when hw-address exceeds 40 hexadecimal digits or 20 characters
+ *          or when other identifiers exceed 256 hexadecimal digits or 128
+ *          characters.
  */
-function identifierRequiredValidator(group: FormGroup): ValidationErrors | null {
+function identifierValidator(group: FormGroup): ValidationErrors | null {
+    const idType = group.get('idType')
     const idInputHex = group.get('idInputHex')
     const idInputText = group.get('idInputText')
+    let valErrors: ValidationErrors = null
     switch (group.get('idFormat').value) {
         case 'hex':
             // User selected hex format. Clear validation errors pertaining
             // to the idInputText and set errors for idInputHex if the
             // required value is not specified.
             idInputText.setErrors(null)
+            valErrors =
+                Validators.required(idInputHex) ||
+                StorkValidators.hexIdentifierLength(idType.value === 'hw-address' ? 40 : 256)(idInputHex)
             if (idInputHex.valid) {
-                idInputHex.setErrors(Validators.required(idInputHex))
+                idInputHex.setErrors(valErrors)
             }
-            return Validators.required(idInputHex)
+            return valErrors
         case 'text':
             // User selected text format.
             idInputHex.setErrors(null)
+            valErrors =
+                Validators.required(idInputText) ||
+                Validators.maxLength(idType.value === 'hw-address' ? 20 : 128)(idInputText)
             if (idInputText.valid) {
-                idInputText.setErrors(Validators.required(idInputText))
+                idInputText.setErrors(valErrors)
             }
-            return Validators.required(idInputText)
+            return valErrors
     }
     return null
 }
 
 /**
- * A form validator checking if a user specified at least one reservation.
+ * A form validator checking if the specified IP address is within a
+ * selected subnet range.
  *
- * Besides IP reservations it is also possible to specify hostname
- * reservation. This validator checks if hostname reservation has been
- * specified. Otherwise, it checks if at least one IP reservation has been
- * specified.
+ * It skips the validation if the IP address is not specified, if the
+ * specified address is invalid, subnet hasn't been selected or the
+ * reservation is global.
  *
- * @param group top-level component form group.
- * @returns validation errors if neither hostname or IP address reservations
- *          have been specified.
+ * @param ipType specified if an IPv4 or IPv6 address is validated.
+ * @param hostForm a host form state.
+ * @returns validator function that returns validation errors when a
+ *          subnet is selected and the specified IPv4 or IPv6 address
+ *          is not in this subnet range.
  */
-function reservationRequiredValidator(group: FormGroup): ValidationErrors | null {
-    // The easiest check is whether the hostname reservation has been
-    // specified.
-    if (!Validators.required(group.get('hostname'))) {
+function addressInSubnetValidator(ipType: IPType, hostForm: HostForm): ValidatorFn {
+    return (control: AbstractControl): ValidationErrors | null => {
+        // The value must be specified, must be a correct IP address, the
+        // reservation must not be global and the subnet must be specified.
+        if (
+            control.value === null ||
+            typeof control.value !== 'string' ||
+            control.value.length === 0 ||
+            !hostForm ||
+            (hostForm.group && hostForm.group.get('globalReservation').value) ||
+            !hostForm.filteredSubnets ||
+            (ipType === IPType.IPv4 && !Validator.isValidIPv4String(control.value)[0]) ||
+            (ipType === IPType.IPv6 && !Validator.isValidIPv6String(control.value)[0])
+        ) {
+            return null
+        }
+        // Convert the address to an IPv4 or IPv6 object.
+        let ipAddress: IPv4 | IPv6
+        ipAddress = ipType === IPType.IPv4 ? IPv4.fromString(control.value) : IPv6.fromString(control.value)
+        if (!ipAddress) {
+            return null
+        }
+        // Find the selected subnet range.
+        const subnetRange = hostForm.getSelectedSubnetRange()
+        if (!subnetRange) {
+            return null
+        }
+        // Make sure the address is within the subnet boundaries.
+        if (ipAddress.isLessThan(subnetRange[1].getFirst()) || ipAddress.isGreaterThan(subnetRange[1].getLast())) {
+            return { 'ip-subnet-range': `IP address is not in the subnet ${subnetRange[0]} range.` }
+        }
         return null
     }
-    // Iterate over the IP reservations and see if they are specified.
-    if (group.get('ipGroups')) {
-        for (let i = 0; i < (group.get('ipGroups') as FormArray).length; i++) {
-            const ipg = (group.get('ipGroups') as FormArray).at(i)
-            switch (ipg.get('ipType').value) {
-                case 'ipv4':
-                    if (!Validators.required(ipg.get('inputIPv4'))) {
-                        return null
-                    }
-                    break
-                case 'ia_na':
-                    if (!Validators.required(ipg.get('inputNA'))) {
-                        return null
-                    }
-                    break
-                case 'ia_pd':
-                    if (!Validators.required(ipg.get('inputPD'))) {
-                        return null
-                    }
-                    break
-            }
-        }
-    }
-    // No hostname nor IP reservation found.
-    return {
-        err: 'at least one IP or hostname reservation is required',
-    }
-}
-
-/**
- * Holds the state of the form created by the HostFormComponent.
- *
- * The state is shared with the parent component via the event emitter
- * and can be used to re-create the HostFormComponent with the already
- * edited form data. It is particularly useful when the component is
- * destroyed as a result of switching between different tabs.
- */
-class HostForm {
-    /**
-     * A boolean value indicating if the updated form was passed to
-     * the parent component when the HostFormComponent was destroyed.
-     *
-     * When the component is re-created it checks this value to decide
-     * whether or not the form should be initialized with default values.
-     */
-    preserved: boolean = false
-
-    /**
-     * A transaction id returned by the server after sending the
-     * request to begin one.
-     */
-    transactionId: number = 0
-
-    /**
-     * An error to begin the transaction returned by the server.
-     */
-    initError: string
-
-    /**
-     * A form group comprising all form controls, arrays and other form
-     * groups (a parent group for the HostFormComponent form).
-     */
-    group: FormGroup
-
-    /**
-     * A list of all daemons that can be selected from the drop down list.
-     */
-    allDaemons: KeaDaemon[]
-
-    /**
-     * A filtered list of daemons comprising only those that match the
-     * type of the first selected daemon.
-     *
-     * Maintaining a filtered list prevents the user from selecting the
-     * servers of different kinds, e.g. one DHCPv4 and one DHCPv6 server.
-     */
-    filteredDaemons: KeaDaemon[]
-
-    /**
-     * A list of subnets that can be selected from the drop down list.
-     *
-     * An actual drop down list can be shorter depending on the list of
-     * selected servers. It displays only the subnets that the selected
-     * servers serve.
-     */
-    allSubnets: Subnet[]
-
-    /**
-     * An array of selectable subnets according to the current form data.
-     *
-     * Suppose a user selected a server in the form. In this case, this
-     * array comprises only the subnets served by this server.
-     */
-    filteredSubnets: Subnet[]
-
-    /**
-     * A flag set to true when DHCPv4 servers have been selected.
-     */
-    dhcpv4: boolean = false
-
-    /**
-     * A flag set to true when DHCPv6 servers have been selected.
-     */
-    dhcpv6: boolean = false
 }
 
 /**
@@ -255,6 +198,26 @@ export class HostFormComponent implements OnInit, OnDestroy {
         },
     ]
 
+    /**
+     * Default placeholder displayed in the IPv4 resevation input box.
+     */
+    static defaultIPv4Placeholder = '?.?.?.?'
+
+    /**
+     * Default placeholder displayed in the IPv6 resevation input box.
+     */
+    static defaultIPv6Placeholder = 'e.g. 2001:db8:1::'
+
+    /**
+     * Current placeholder displayed in the IPv4 resevation input box.
+     */
+    ipv4Placeholder = HostFormComponent.defaultIPv4Placeholder
+
+    /**
+     * Current placeholder displayed in the IPv6 resevation input box.
+     */
+    ipv6Placeholder = HostFormComponent.defaultIPv6Placeholder
+
     /**
      * Constructor.
      *
@@ -305,14 +268,15 @@ export class HostFormComponent implements OnInit, OnDestroy {
                         idFormat: ['hex'],
                     },
                     {
-                        validators: [identifierRequiredValidator],
+                        validators: [identifierValidator],
                     }
                 ),
                 ipGroups: this._formBuilder.array([this._createNewIPGroup()]),
-                hostname: [''],
+                hostname: ['', StorkValidators.fqdn],
+                options: this._formBuilder.array([]),
             },
             {
-                validators: [subnetRequiredValidator, reservationRequiredValidator],
+                validators: [subnetRequiredValidator],
             }
         )
 
@@ -541,8 +505,14 @@ export class HostFormComponent implements OnInit, OnDestroy {
     private _createNewIPGroup(defaultType = 'ipv4'): FormGroup {
         return this._formBuilder.group({
             ipType: [defaultType],
-            inputIPv4: ['', StorkValidators.ipv4()],
-            inputNA: ['', StorkValidators.ipv6()],
+            inputIPv4: [
+                '',
+                Validators.compose([StorkValidators.ipv4(), addressInSubnetValidator(IPType.IPv4, this.form)]),
+            ],
+            inputNA: [
+                '',
+                Validators.compose([StorkValidators.ipv6(), addressInSubnetValidator(IPType.IPv6, this.form)]),
+            ],
             inputPD: ['', StorkValidators.ipv6()],
             inputPDLength: ['64', Validators.required],
         })
@@ -563,6 +533,15 @@ export class HostFormComponent implements OnInit, OnDestroy {
         }
     }
 
+    /**
+     * Convenience function returning the form array with DHCP options.
+     *
+     * @returns form array with DHCP options.
+     */
+    get optionsArray(): FormArray {
+        return this.formGroup.get('options') as FormArray
+    }
+
     /**
      * A callback invoked when selected DHCP servers have changed.
      *
@@ -644,6 +623,56 @@ export class HostFormComponent implements OnInit, OnDestroy {
         }
     }
 
+    /**
+     * A callback called when a subnet has been selected or de-selected.
+     *
+     * It iterates over the specified IP addresses and checks if they belong
+     * to the new subnet boundaries. It also updates the placeholders of the
+     * respective input boxes. The placeholders contain IP addresses suitable
+     * for the selected subnet.
+     */
+    onSelectedSubnetChange(): void {
+        for (let i = 0; i < this.ipGroups.length; i++) {
+            this.ipGroups.at(i).get('inputIPv4').updateValueAndValidity()
+            this.ipGroups.at(i).get('inputNA').updateValueAndValidity()
+        }
+        const range = this.form.getSelectedSubnetRange()
+        if (range) {
+            let first = range[1].getFirst()
+            if (isIPv4(first)) {
+                this.ipv4Placeholder = `in range of ${first.toString()} - ${range[1].getLast()}`
+            } else {
+                this.ipv6Placeholder = collapseIPv6Number(first.toString())
+            }
+        } else {
+            this.ipv4Placeholder = HostFormComponent.defaultIPv4Placeholder
+            this.ipv6Placeholder = HostFormComponent.defaultIPv6Placeholder
+        }
+    }
+
+    /**
+     * A callback called when new host identifier type has been selected.
+     *
+     * It updates the validity of the input fields in which the identifier is
+     * specified.
+     */
+    onSelectedIdentifierChange(): void {
+        if (this.formGroup.get('hostIdGroup.idFormat').value === 'hex') {
+            this.formGroup.get('hostIdGroup.idInputHex').updateValueAndValidity()
+        } else {
+            this.formGroup.get('hostIdGroup.idInputText').updateValueAndValidity()
+        }
+    }
+
+    /**
+     * A function called when a user clicked to add a new option form.
+     *
+     * It creates a new default form group for the option.
+     */
+    onOptionAdd(): void {
+        this.optionsArray.push(createDefaultDhcpOptionFormGroup(this.form.dhcpv6 ? IPType.IPv6 : IPType.IPv4))
+    }
+
     /**
      * A function called when a user attempts to submit the new host reservation.
      *
@@ -656,6 +685,24 @@ export class HostFormComponent implements OnInit, OnDestroy {
             ? 0
             : this.formGroup.get('selectedSubnet').value
 
+        // DHCP options.
+        let options = []
+        if (this.optionsArray) {
+            try {
+                const optionsForm = new DhcpOptionSetForm(this.optionsArray)
+                optionsForm.process(this.form.dhcpv4 ? IPType.IPv4 : IPType.IPv6)
+                options = optionsForm.getSerializedOptions()
+            } catch (err) {
+                this._messageService.add({
+                    severity: 'error',
+                    summary: 'Cannot commit new host',
+                    detail: 'Processing specified DHCP options failed: ' + err,
+                    life: 10000,
+                })
+                return
+            }
+        }
+
         // Create associations with the daemons.
         let localHosts: LocalHost[] = []
         const selectedDaemons = this.formGroup.get('selectedDaemons').value
@@ -663,6 +710,7 @@ export class HostFormComponent implements OnInit, OnDestroy {
             localHosts.push({
                 daemonId: id,
                 dataSource: 'api',
+                options: options,
             })
         }
 
