@@ -22,28 +22,26 @@ describe('SharedNetworksPageComponent', () => {
     let fixture: ComponentFixture<SharedNetworksPageComponent>
     let dhcpService: DHCPService
 
-    beforeEach(
-        waitForAsync(() => {
-            TestBed.configureTestingModule({
-                imports: [
-                    FormsModule,
-                    DropdownModule,
-                    TableModule,
-                    TooltipModule,
-                    HttpClientTestingModule,
-                    BreadcrumbModule,
-                    OverlayPanelModule,
-                    NoopAnimationsModule,
-                    RouterModule,
-                    RouterTestingModule,
-                ],
-                declarations: [SharedNetworksPageComponent, SubnetBarComponent, BreadcrumbsComponent, HelpTipComponent],
-                providers: [DHCPService],
-            })
-
-            dhcpService = TestBed.inject(DHCPService)
+    beforeEach(waitForAsync(() => {
+        TestBed.configureTestingModule({
+            imports: [
+                FormsModule,
+                DropdownModule,
+                TableModule,
+                TooltipModule,
+                HttpClientTestingModule,
+                BreadcrumbModule,
+                OverlayPanelModule,
+                NoopAnimationsModule,
+                RouterModule,
+                RouterTestingModule,
+            ],
+            declarations: [SharedNetworksPageComponent, SubnetBarComponent, BreadcrumbsComponent, HelpTipComponent],
+            providers: [DHCPService],
         })
-    )
+
+        dhcpService = TestBed.inject(DHCPService)
+    }))
 
     beforeEach(() => {
         const fakeResponses: any = [
@@ -62,20 +60,20 @@ describe('SharedNetworksPageComponent', () => {
                                         id: 1,
                                         machineAddress: 'localhost',
                                         machineHostname: 'lv-pc',
-                                        stats: {
-                                            'assigned-addresses':
-                                                '12345678901234567890123456789012345678901234567890123456789012345678901234567890',
-                                            'total-addresses':
-                                                '1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890',
-                                            'declined-addresses': '-2',
-                                        },
-                                        statsCollectedAt: '2022-01-19T12:10:22.513Z',
                                     },
                                 ],
                                 pools: ['1.0.0.4-1.0.255.254'],
                                 subnet: '1.0.0.0/16',
                             },
                         ],
+                        stats: {
+                            'assigned-addresses':
+                                '12345678901234567890123456789012345678901234567890123456789012345678901234567890',
+                            'total-addresses':
+                                '1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890',
+                            'declined-addresses': '-2',
+                        },
+                        statsCollectedAt: '2022-01-19T12:10:22.513Z',
                     },
                 ],
                 total: 10496,
@@ -95,13 +93,13 @@ describe('SharedNetworksPageComponent', () => {
                                         id: 1,
                                         machineAddress: 'localhost',
                                         machineHostname: 'lv-pc',
-                                        statsCollectedAt: '1970-01-01T12:00:00.0Z',
                                     },
                                 ],
                                 pools: ['1.0.0.4-1.0.255.254'],
                                 subnet: '1.0.0.0/16',
                             },
                         ],
+                        statsCollectedAt: '1970-01-01T12:00:00.0Z',
                     },
                 ],
                 total: 10496,
@@ -128,7 +126,7 @@ describe('SharedNetworksPageComponent', () => {
         await fixture.whenStable()
 
         // Assert
-        const stats: { [key: string]: BigInt } = component.networks[0].subnets[0].localSubnets[0].stats
+        const stats: { [key: string]: BigInt } = component.networks[0].stats
         expect(stats['assigned-addresses']).toBe(
             BigInt('12345678901234567890123456789012345678901234567890123456789012345678901234567890')
         )
@@ -146,7 +144,7 @@ describe('SharedNetworksPageComponent', () => {
         await fixture.whenStable()
 
         // Assert
-        expect(component.networks[0].subnets[0].localSubnets[0].stats).toBeUndefined()
+        expect(component.networks[0].stats).toBeUndefined()
         // No throw
     })
 })
